@@ -1,5 +1,5 @@
 /*
-   $Id: Pg.h,v 1.7 2005/05/13 20:55:57 turnstep Exp $
+   $Id: Pg.h,v 1.11 2005/08/26 01:39:46 turnstep Exp $
 
    Copyright (c) 2000-2004 PostgreSQL Global Development Group
    Copyright (c) 1997,1998,1999,2000 Edmund Mergl
@@ -15,6 +15,9 @@
 static int errno;
 #endif
 
+#define DBDPG_TRUE 1
+#define DBDPG_FALSE 0
+
 #include "libpq-fe.h"
 
 #ifdef NEVER
@@ -44,10 +47,11 @@ static int errno;
 
 #include <DBIXS.h>		/* installed by the DBI module	*/
 
-#include "dbdimp.h"		/* read in our implementation details */
-
 #include <dbd_xsh.h>		/* installed by the DBI module	*/
 
+#include "dbdimp.h"
+#include "quote.h"
+#include "types.h"
 
 /* defines for Driver.xst to let it know what functions to include */
 #define dbd_st_rows dbd_st_rows
